@@ -10,7 +10,7 @@ Business::Shipping::UPS_Offline::RateRequest
 
 =head1 VERSION
 
-$Rev: 301 $
+$Rev: 311 $
 
 =head1 GLOSSARY
 
@@ -26,7 +26,7 @@ $Rev: 301 $
 
 =cut
 
-$VERSION = do { my $r = q$Rev: 301 $; $r =~ /\d+/; $&; };
+$VERSION = do { my $r = q$Rev: 311 $; $r =~ /\d+/; $&; };
 
 use strict;
 use warnings;
@@ -44,6 +44,7 @@ use POSIX qw{ ceil strftime };
 #use Math::BaseCnv;
 #use Data::Dumper;
 use Storable;
+use Cwd;
 
 =head2 update
 
@@ -121,6 +122,7 @@ use Class::MethodMaker 2.0
                                     'from_ak_or_hi',
                                     'from_state',
                                     'from_state_abbrev',
+                                    'tier',
                                 ],
                    },
                    'shipment'
@@ -392,11 +394,10 @@ services, for example).
 
 =cut
 
-# TODO: Instead of always applying this, only apply it if the zip is found
-# in xarea.
-
 # TODO: Calculate the delivery area surcharge amount from the accessorials.csv
 
+# TODO: Handle international too.
+
 sub calc_delivery_area_surcharge
 {
     my ( $self ) = @_;
@@ -596,7 +597,13 @@ sub load_table
         my $filename = Business::Shipping::Config::data_dir . "/$table.dat";
         debug "loading filename $filename";
         if ( ! -f $filename ) {
-            return error "file does not exist: $filename";
+            # Current working directory is useful to know if the $filename is not an absolute path.
+            my $error_append = '';
+            if ( $filename !~ m|^/| ) {
+                my $cur_working_dir = Cwd::cwd();
+                $error_append = " (current working dir: $cur_working_dir)";
+            }
+            return error "file does not exist: ${filename}${error_append}";
         }
         $self->Data->{ $table } = Storable::retrieve( $filename );
     }
@@ -754,7 +761,6 @@ sub calc_cost
     # Requires that it be multi-package, over a certain total weight, and only certain services.
     # 100 pounds for airborn services, 200 pounds for ground (Ground, 3DS)
     my $cost;
-    
     if ( $self->shipment->use_hundred_weight ) {
         my $weight = $self->shipment->weight;
         
@@ -766,18 +772,28 @@ sub calc_cost
         debug "Using hundredweight with table $h_table";
         
         my $rate_val = $self->get_cost( $h_table, $self->zone, $weight );
+        
+        if ( ! $rate_val and $self->tier ) {
+            # Many tier tables are not implemented yet.  
+            # TODO: remove this after all the tier levels are implemented for all the services.
+            debug "No rate for tier '" . $self->tier . "'.  Try removing tier.";
+            $h_table =~ s/\d$//;
+            $rate_val = $self->get_cost( $h_table, $self->zone, $weight );
+        }
+        
         if (    $self->shipment->cwt_is_per eq 'hundredweight' ) {
             my $number_of_hundred_pounds = $weight * 0.01;
             my $rate_per_hundred_pounds = $rate_val;
             $cost = $number_of_hundred_pounds * $rate_per_hundred_pounds;
+            debug "cwt is per hundredweight, num of hundredpounds ($number_of_hundred_pounds) * rate_per_hund ($rate_per_hundred_pounds) = cost ($cost)";
         }
         elsif ( $self->shipment->cwt_is_per eq 'pound' ) {
             $cost = $rate_val * $weight;
+            debug "cwt is per pound, rate val ($rate_val) * weight ($weight ) = cost ($cost)";
         }
         else {
             error "unknown is_per type";
         }
-        
     }
     else {
         my $running_sum_cost;
@@ -924,6 +940,8 @@ sub binary_numeric
 {
     my ( $array, $target ) = @_;
     
+    return unless ref $array eq 'ARRAY';
+    
     # $low is first element that is not too low;
     # $high is the first that is too high
     my ( $low, $high ) = ( 0, scalar( @$array ) );
